@@ -1,14 +1,7 @@
 from typing import List, Union
 
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtBluetooth
-elif PYSIDE2:
-    from PySide2 import QtBluetooth
-
 from prettyqt import bluetooth, core
+from prettyqt.qt import QtBluetooth
 from prettyqt.utils import bidict
 
 
