@@ -1,8 +1,7 @@
 from __future__ import annotations
 
-from qtpy.QtCharts import QtCharts
-
 from prettyqt import charts
+from prettyqt.qt.QtCharts import QtCharts
 
 
 QtCharts.QBarCategoryAxis.__bases__ = (charts.AbstractAxis,)
