@@ -1,6 +1,5 @@
-from qtpy import QtCore
-
 from prettyqt import constants
+from prettyqt.qt import QtCore
 from prettyqt.utils import InvalidParamError
 
 
