@@ -1,8 +1,7 @@
 from typing import List, Literal
 
-from qtpy import QtCore
-
 from prettyqt import core
+from prettyqt.qt import QtCore
 
 
 LoadHintStr = Literal[
