@@ -1,9 +1,8 @@
 import pathlib
-from typing import Optional
-
-from qtpy import QtCore
+from typing import Optional, Union
 
 from prettyqt import core
+from prettyqt.qt import QtCore
 
 
 QtCore.QTranslator.__bases__ = (core.Object,)
@@ -18,3 +17,6 @@ class Translator(QtCore.QTranslator):
         if not path:
             return None
         return pathlib.Path(path)
+
+    def load_file(self, path: Union[str, pathlib.Path]) -> bool:
+        return self.load(str(path))
