@@ -2,8 +2,8 @@ from __future__ import annotations
 
 import sys
 
-import qtpy
-from qtpy import QtCore
+import prettyqt.qt
+from prettyqt.qt import QtCore
 
 
 class VersionNumber(QtCore.QVersionNumber):
@@ -36,6 +36,9 @@ class VersionNumber(QtCore.QVersionNumber):
             other = VersionNumber(other)
         return super().__eq__(other)
 
+    def __hash__(self):
+        return hash((self.major(), self.minor(), self.micro()))
+
     def __gt__(self, other):
         if isinstance(other, (str, tuple)):
             other = VersionNumber(other)
@@ -58,7 +61,7 @@ class VersionNumber(QtCore.QVersionNumber):
 
     @classmethod
     def get_qt_version(cls) -> VersionNumber:
-        return cls(*[int(i) for i in qtpy.QT_VERSION.split(".")])
+        return cls(*[int(i) for i in prettyqt.qt.QT_VERSION.split(".")])
 
     @classmethod
     def get_python_version(cls) -> VersionNumber:
@@ -75,3 +78,7 @@ class VersionNumber(QtCore.QVersionNumber):
     def micro(self) -> int:
         """An integer representing the micro version."""
         return self.microVersion()
+
+
+if __name__ == "__main__":
+    version = VersionNumber(3, 0, 0)
