@@ -2,9 +2,8 @@ from dataclasses import dataclass
 import logging
 from typing import Callable, List, Optional, Union
 
-from qtpy import QtCore, QtGui
-
 from prettyqt import constants, core, gui
+from prettyqt.qt import QtCore, QtGui
 
 
 logger = logging.getLogger(__name__)
@@ -165,3 +164,19 @@ class ColumnItemModel(core.AbstractItemModel):
             return self._attr_cols[section].name
         else:
             return None
+
+
+if __name__ == "__main__":
+    from prettyqt import widgets
+
+    class TestModel(ColumnItemModel):
+        def rowCount(self, parent=None):
+            return 5
+
+    app = widgets.app()
+    item = ColumnItem(name="Test", label=None)
+    model = TestModel(attr_cols=[item])
+    table = widgets.TableView()
+    table.set_model(model)
+    table.show()
+    app.main_loop()
