@@ -1,8 +1,7 @@
 from typing import Dict, Iterable, Iterator, Literal, Mapping, Optional, Tuple, Union
 
-from qtpy import QtWidgets
-
 from prettyqt import core, widgets
+from prettyqt.qt import QtWidgets
 
 
 class FlagSelectionWidget(widgets.GroupBox):
@@ -37,7 +36,7 @@ class FlagSelectionWidget(widgets.GroupBox):
         checkbox = widgets.CheckBox(title)
         checkbox.toggled.connect(self.update_choice)
         self.buttons[checkbox] = flag
-        self.box += checkbox
+        self.box.add(checkbox)
 
     def current_choice(self) -> int:
         ret_val = 0
