@@ -1,8 +1,8 @@
 from typing import Optional
 
-from qtpy import QtWidgets
-
 from prettyqt import iconprovider, widgets
+from prettyqt.qt import QtWidgets
+from prettyqt.utils import types
 
 
 class IconLabel(widgets.Widget):
@@ -10,7 +10,7 @@ class IconLabel(widgets.Widget):
         self,
         text: Optional[str] = None,
         tooltip: str = "",
-        icon: iconprovider.IconType = "mdi.help-circle-outline",
+        icon: types.IconType = "mdi.help-circle-outline",
         parent: Optional[QtWidgets.QWidget] = None,
     ):
         super().__init__(parent=parent)
@@ -25,8 +25,8 @@ class IconLabel(widgets.Widget):
         self.icon.set_size_policy(horizontal="minimum")
         pixmap = icon.pixmap(20, 20)
         self.icon.setPixmap(pixmap)
-        self.box += self.label
-        self.box += self.icon
+        self.box.add(self.label)
+        self.box.add(self.icon)
         self.box.setSpacing(0)
         self.box.addStretch()
 
