@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from prettyqt import widgets
 from prettyqt.utils import bidict
 
@@ -17,7 +15,7 @@ class MappedCheckBox(widgets.CheckBox):
         return self.map[self.isChecked()]
 
     def set_value(self, value):
-        val = self.map.inv[value]
+        val = self.map.inverse[value]
         super().set_value(val)
 
 
@@ -25,5 +23,5 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = MappedCheckBox("Test")
     widget.show()
-    app.exec_()
+    app.main_loop()
     print(widget.get_value())
