@@ -1,8 +1,7 @@
 from typing import Optional
 
-from qtpy import QtCore, QtWidgets
-
 from prettyqt import core, gui, widgets
+from prettyqt.qt import QtCore, QtWidgets
 
 
 class PopupInfo(widgets.Dialog):
@@ -25,7 +24,7 @@ class PopupInfo(widgets.Dialog):
         self.set_layout(layout)
         self.set_background_color("black")
         self.label.set_color("white")
-        layout += self.label
+        layout.add(self.label)
         # signals.signals.popup_info.connect(self.popup)
 
     def show(self):
