@@ -1,8 +1,7 @@
 from typing import Optional
 
-from qtpy import QtWidgets
-
 from prettyqt import widgets
+from prettyqt.qt import QtWidgets
 
 
 class SingleLineTextEdit(widgets.PlainTextEdit):
@@ -10,8 +9,8 @@ class SingleLineTextEdit(widgets.PlainTextEdit):
         super().__init__(parent=parent)
         self.textChanged.connect(self._on_text_changed)
         font_metrics = self.get_font_metrics()
-        self.row_height = font_metrics.lineSpacing()
-        self.setFixedHeight(int(self.row_height * 1.5))
+        row_height = font_metrics.lineSpacing()
+        self.setFixedHeight(int(row_height * 1.5))
         self.set_size_policy(vertical="fixed")
         self.set_line_wrap_mode("none")
         self.set_scrollbar_policy("always_off")
