@@ -1,6 +1,5 @@
-from qtpy import QtGui
-
 from prettyqt import constants, core
+from prettyqt.qt import QtGui
 from prettyqt.utils import InvalidParamError
 
 
@@ -12,8 +11,8 @@ class FontMetricsF(QtGui.QFontMetricsF):
             raise InvalidParamError(mode, constants.ELIDE_MODE)
         return self.elidedText(text, constants.ELIDE_MODE[mode], width, flags)
 
-    def get_bounding_rect(self, *args, **kwargs) -> core.RectF:
-        return core.RectF(self.boundingRect(*args, **kwargs))
+    def get_bounding_rect(self, *args) -> core.RectF:
+        return core.RectF(self.boundingRect(*args))
 
     def get_tight_bounding_rect(self, text: str) -> core.RectF:
         return core.RectF(self.tightBoundingRect(text))
