@@ -1,8 +1,7 @@
 from typing import Tuple
 
-from qtpy import QtGui
-
 from prettyqt import core, gui
+from prettyqt.qt import QtGui
 
 
 QtGui.QImage.__bases__ = (gui.PaintDevice,)
