@@ -1,9 +1,8 @@
 from typing import Dict, Literal
 
-from qtpy import QtGui
-
 from prettyqt import core, gui
-from prettyqt.utils import InvalidParamError, bidict, colors
+from prettyqt.qt import QtGui
+from prettyqt.utils import InvalidParamError, bidict, colors, types
 
 
 ROLE = bidict(
@@ -76,7 +75,7 @@ class Palette(QtGui.QPalette):
     def __getitem__(self, index: RoleStr) -> gui.Color:
         return self.get_color(index)
 
-    def __setitem__(self, index: RoleStr, value: colors.ColorType):
+    def __setitem__(self, index: RoleStr, value: types.ColorType):
         self.set_color(index, value)
 
     def __bytes__(self):
@@ -91,7 +90,7 @@ class Palette(QtGui.QPalette):
         self.setColor(self.Inactive, self.Highlight, color)
 
     def set_color(
-        self, role: RoleStr, color: colors.ColorType, group: GroupStr = "active"
+        self, role: RoleStr, color: types.ColorType, group: GroupStr = "active"
     ):
         color = colors.get_color(color)
         self.setColor(GROUP[group], ROLE[role], color)
@@ -103,7 +102,7 @@ class Palette(QtGui.QPalette):
         return gui.Color(self.color(GROUP[group], ROLE[role]))
 
     def set_brush(
-        self, role: RoleStr, brush: colors.ColorAndBrushType, group: GroupStr = "active"
+        self, role: RoleStr, brush: types.ColorAndBrushType, group: GroupStr = "active"
     ):
         if not isinstance(brush, QtGui.QBrush):
             brush = gui.Brush(colors.get_color(brush))
