@@ -1,7 +1,6 @@
-from qtpy import QtGui
-
 from prettyqt import constants, core, gui
-from prettyqt.utils import InvalidParamError, colors
+from prettyqt.qt import QtGui
+from prettyqt.utils import InvalidParamError, colors, types
 
 
 class Pen(QtGui.QPen):
@@ -21,7 +20,7 @@ class Pen(QtGui.QPen):
     def __repr__(self):
         return f"{type(self).__name__}({self.get_color()})"
 
-    def set_color(self, color: colors.ColorType):
+    def set_color(self, color: types.ColorType):
         color = colors.get_color(color)
         self.setColor(color)
 
