@@ -1,8 +1,7 @@
 from typing import Iterator, List
 
-from qtpy import QtGui
-
 from prettyqt import gui
+from prettyqt.qt import QtGui
 
 
 QtGui.QTextBlockGroup.__bases__ = (gui.TextObject,)
