@@ -1,6 +1,5 @@
-from qtpy import QtMultimedia
-
 from prettyqt import multimedia
+from prettyqt.qt import QtMultimedia
 
 
 QtMultimedia.QAudioRecorder.__bases__ = (multimedia.MediaRecorder,)
