@@ -1,6 +1,5 @@
-from qtpy import QtCore, QtMultimediaWidgets
-
 from prettyqt import multimedia, widgets
+from prettyqt.qt import QtCore, QtMultimediaWidgets
 
 
 QtMultimediaWidgets.QVideoWidget.__bases__ = (
