@@ -1,6 +1,5 @@
-from qtpy import QtNetwork
-
 from prettyqt import network
+from prettyqt.qt import QtNetwork
 
 
 QtNetwork.QTcpSocket.__bases__ = (network.AbstractSocket,)
