@@ -1,6 +1,5 @@
-from qtpy import QtQuick
-
 from prettyqt import core
+from prettyqt.qt import QtQuick
 
 
 QtQuick.QQuickImageResponse.__bases__ = (core.Object,)
