@@ -1,15 +1,8 @@
 import logging
 from typing import List, Literal
 
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtTextToSpeech  # type: ignore
-elif PYSIDE2:
-    from PySide2 import QtTextToSpeech
-
 from prettyqt import core, texttospeech
+from prettyqt.qt import QtTextToSpeech
 from prettyqt.utils import bidict
 
 
