@@ -1,12 +1,5 @@
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtWebEngineCore  # type: ignore
-elif PYSIDE2:
-    from PySide2 import QtWebEngineCore
-
 from prettyqt import core
+from prettyqt.qt import QtWebEngineCore
 
 
 QtWebEngineCore.QWebEngineUrlSchemeHandler.__bases__ = (core.Object,)
