@@ -1,16 +1,9 @@
-# from qtpy import QtWebEngineWidgets
+# from prettyqt.qt import QtWebEngineWidgets
 
 from typing import Iterator, List
 
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtWebEngineWidgets  # type: ignore
-elif PYSIDE2:
-    from PySide2 import QtWebEngineWidgets
-
 from prettyqt import webenginewidgets
+from prettyqt.qt import QtWebEngineWidgets
 
 
 class WebEngineHistory:
