@@ -1,12 +1,5 @@
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtWebEngineWidgets  # type: ignore
-elif PYSIDE2:
-    from PySide2 import QtWebEngineWidgets
-
 from prettyqt import core
+from prettyqt.qt import QtWebEngineWidgets
 
 
 class WebEngineHistoryItem(QtWebEngineWidgets.QWebEngineHistoryItem):
