@@ -1,9 +1,8 @@
 from typing import Tuple, Union
 
-from qtpy import QtCore, QtGui, QtWidgets
-
 from prettyqt import core, gui, iconprovider, widgets
-from prettyqt.utils import InvalidParamError
+from prettyqt.qt import QtCore, QtGui, QtWidgets
+from prettyqt.utils import InvalidParamError, types
 
 
 QtWidgets.QAbstractButton.__bases__ = (widgets.Widget,)
@@ -45,7 +44,7 @@ class AbstractButton(QtWidgets.QAbstractButton):
     def __bool__(self):
         return self.isChecked()
 
-    def set_icon(self, icon: iconprovider.IconType):
+    def set_icon(self, icon: types.IconType):
         """Set the icon for the button.
 
         Args:
@@ -73,11 +72,12 @@ class AbstractButton(QtWidgets.QAbstractButton):
     def set_shortcut(self, shortcut: Union[None, QtGui.QKeySequence, str]):
         if shortcut is None:
             shortcut = ""
-        seq = gui.KeySequence(shortcut)
-        self.setShortcut(seq)
+        if isinstance(shortcut, str):
+            shortcut = gui.KeySequence(shortcut, gui.KeySequence.PortableText)
+        self.setShortcut(shortcut)
 
     def get_shortcut(self) -> gui.KeySequence:
-        return gui.KeySequence(self.shortcut())
+        return gui.KeySequence(self.shortcut().toString(), gui.KeySequence.PortableText)
 
     def set_text(self, text: str):
         self.setText(text)
