@@ -1,8 +1,7 @@
 from typing import Literal, Optional
 
-from qtpy import QtCore, QtWidgets
-
 from prettyqt import core
+from prettyqt.qt import QtCore, QtWidgets
 from prettyqt.utils import InvalidParamError, bidict
 
 
@@ -30,7 +29,17 @@ class ActionGroup(QtWidgets.QActionGroup):
         return self.actions()[item]
 
     def serialize_fields(self):
-        return dict(exclusion_policy=self.get_exclusion_policy())
+        return dict(
+            exclusion_policy=self.get_exclusion_policy(),
+            visible=self.isVisible(),
+            enabled=self.isEnabled(),
+        )
+
+    def __setstate__(self, state):
+        super().__setstate__(state)
+        self.setEnabled(state.get("enabled", ""))
+        self.setVisible(state.get("visible", ""))
+        self.set_exclusion_policy(state.get("exclusion_policy", ""))
 
     def set_exclusion_policy(self, policy: Optional[ExclusionPolicyStr]):
         """Set exclusion policy to use.
