@@ -1,9 +1,8 @@
 import datetime
 from typing import Union
 
-from qtpy import QtCore, QtWidgets
-
 from prettyqt import core, widgets
+from prettyqt.qt import QtCore, QtWidgets
 
 
 QtWidgets.QDateEdit.__bases__ = (widgets.DateTimeEdit,)
@@ -28,7 +27,7 @@ class DateEdit(QtWidgets.QDateEdit):
         )
 
     def set_value(self, value: Union[QtCore.QDate, datetime.date]):
-        return self.setDate(value)
+        self.setDate(value)  # type: ignore
 
     def set_range(
         self,
