@@ -1,8 +1,7 @@
 from typing import Literal, Tuple, Union
 
-from qtpy import QtCore, QtWidgets
-
 from prettyqt import constants, gui, widgets
+from prettyqt.qt import QtCore, QtWidgets
 from prettyqt.utils import InvalidParamError
 
 
