@@ -3,10 +3,9 @@ from __future__ import annotations
 import pathlib
 from typing import List, Literal, Optional, Union
 
-from qtpy import QtCore, QtWidgets
-
 from prettyqt import constants, core, gui, widgets
-from prettyqt.utils import InvalidParamError, bidict, colors, helpers
+from prettyqt.qt import QtCore, QtWidgets
+from prettyqt.utils import InvalidParamError, bidict, colors, helpers, types
 
 
 TEXT_INTERACTION = bidict(
@@ -220,7 +219,7 @@ class Label(QtWidgets.QLabel):
         self.setFont(font)
         return self
 
-    def set_color(self, color: colors.ColorType) -> Label:
+    def set_color(self, color: types.ColorType) -> Label:
         with self.edit_stylesheet() as ss:
             if color is None:
                 ss.color.setValue("")
