@@ -1,4 +1,4 @@
-from qtpy import QtWidgets
+from prettyqt.qt import QtWidgets
 
 
 class LayoutItem(QtWidgets.QLayoutItem):
