@@ -1,6 +1,5 @@
-from qtpy import QtWidgets
-
 from prettyqt import constants, core, gui
+from prettyqt.qt import QtWidgets
 from prettyqt.utils import InvalidParamError
 
 
@@ -9,7 +8,7 @@ QtWidgets.QShortcut.__bases__ = (core.Object,)
 
 class Shortcut(QtWidgets.QShortcut):
     def __str__(self):
-        return str(self.get_key())
+        return self.key().toString()
 
     def __int__(self):
         return self.id()
@@ -50,4 +49,4 @@ class Shortcut(QtWidgets.QShortcut):
         Returns:
             Key sequence
         """
-        return gui.KeySequence(self.key())
+        return gui.KeySequence(self.key().toString(), gui.KeySequence.PortableText)
