@@ -4,10 +4,10 @@ from typing import Any, Callable, Dict, Iterator, Literal, Optional, Union
 from deprecated import deprecated
 import qstylizer.parser
 import qstylizer.style
-from qtpy import QtCore, QtGui, QtWidgets
 
 from prettyqt import constants, core, gui, iconprovider, widgets
-from prettyqt.utils import InvalidParamError, colors, helpers, prettyprinter
+from prettyqt.qt import QtCore, QtGui, QtWidgets
+from prettyqt.utils import InvalidParamError, colors, helpers, prettyprinter, types
 
 
 QtWidgets.QWidget.__bases__ = (core.Object, QtGui.QPaintDevice)
@@ -17,6 +17,8 @@ LayoutStr = Literal["horizontal", "vertical", "grid", "form", "stacked", "flow"]
 
 
 class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
+    box: QtWidgets.QLayout
+
     def __repr__(self) -> str:
         cls_name = type(self).__name__
         params = helpers.format_kwargs(self.serialize_fields())
@@ -72,7 +74,7 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
         else:
             super().resize(*size)
 
-    def set_icon(self, icon: iconprovider.IconType) -> None:
+    def set_icon(self, icon: types.IconType) -> None:
         """Set the window icon.
 
         Args:
@@ -269,7 +271,7 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
     def get_palette(self) -> gui.Palette:
         return gui.Palette(self.palette())
 
-    def set_background_color(self, color: colors.ColorType) -> None:
+    def set_background_color(self, color: types.ColorType) -> None:
         col_str = "" if color is None else colors.get_color(color).name()
         with self.edit_stylesheet() as ss:
             ss.backgroundColor.setValue(col_str)
