@@ -1,8 +1,7 @@
 from typing import Optional
 
-from qtpy import QtCore, QtWidgets
-
 from prettyqt import widgets
+from prettyqt.qt import QtCore, QtWidgets
 
 
 QtWidgets.QWidgetAction.__bases__ = (widgets.Action,)
@@ -11,6 +10,7 @@ QtWidgets.QWidgetAction.__bases__ = (widgets.Action,)
 class WidgetAction(QtWidgets.QWidgetAction):
     def __init__(self, parent: Optional[QtCore.QObject] = None):
         super().__init__(parent)  # type: ignore
+        self._menu = None  # bc of PySide inheritance also defined here
 
     #     self.set_text(text)
     #     self.set_icon(icon)
