@@ -1,12 +1,5 @@
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtWinExtras  # type: ignore
-elif PYSIDE2:
-    from PySide2 import QtWinExtras
-
 from prettyqt import core, winextras
+from prettyqt.qt import QtWinExtras
 
 
 QtWinExtras.QWinJumpList.__bases__ = (core.Object,)
